spoon.routing.meshrouter.RoutingProtocolError

Package spoon :: Package routing :: Module meshrouter :: Class RoutingProtocolError |
[hide private]
[frames] | no frames]

# Class RoutingProtocolError

source code

    exceptions.Exception --+
                           |
                          RoutingProtocolError

Known Subclasses:
  NodeUnreachable

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`